pub struct Workspace {
pub members: BTreeSet<String>,
pub default_members: BTreeSet<String>,
pub package: Option<PackageTemplate>,
pub exclude: BTreeSet<String>,
pub metadata: BTreeMap<String, Value>,
pub resolver: Option<Resolver>,
pub dependencies: BTreeMap<String, Dependency>,
pub lints: Option<Lints>,
}Expand description
Workspace settings.
Fields
members: BTreeSet<String>Relative paths of crates in this workspace.
default_members: BTreeSet<String>Members to operate on when in the workspace root.
When specified, default-members must expand to a subset of members.
package: Option<PackageTemplate>Settings that can be inherited by packages in this workspace.
exclude: BTreeSet<String>Ignore these dirs
metadata: BTreeMap<String, Value>Custom settings for the workspace.
resolver: Option<Resolver>The resolver to use for the workspace.
dependencies: BTreeMap<String, Dependency>Dependencies that can be inherited by packages in the workspace.
lints: Option<Lints>Workspace-level lint groups, which can be inherited by packages.